@@ -468,15 +468,6 @@ class MainWindow(AbstractQItem, QMainWindow, QAbstractYAMLObjectSingleton):
         te = TracebackException.from_exception(e.parent_error)
         logging.error(''.join(te.format()))
 
-        if isinstance(e.parent_error, SyntaxError) and (
-            'source code string cannot contain null bytes' in str(
-                e.parent_error).lower()
-        ):
-            logging.error(
-                'If you\'re trying to open a video you first have to install '
-                'the vssource package and have it working with a source plugin!'
-            )
-
         self.script_exec_failed = True
         self.handle_script_error(
             '\n'.join([
@@ -703,7 +694,7 @@ class MainWindow(AbstractQItem, QMainWindow, QAbstractYAMLObjectSingleton):
             graphics_view.graphics_scene.init_scenes()
 
     def clean_core_references(self) -> None:
-        from vstools.utils.vs_proxy import clear_cache
+        from vstools import vs as vs_proxy
 
         for graphics_view in self.graphics_views:
             graphics_view.graphics_scene.clear()
@@ -722,7 +713,7 @@ class MainWindow(AbstractQItem, QMainWindow, QAbstractYAMLObjectSingleton):
 
         try:
             with self.env:
-                clear_cache()
+                vs_proxy.core.clear_cache()
         except Exception:
             ...
 
